summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorPeng Wu <alexepico@gmail.com>2013-11-13 15:45:28 +0800
committerPeng Wu <alexepico@gmail.com>2013-11-13 15:45:28 +0800
commita8c700f1154aacfd1c5ca808a53b393f2f763e63 (patch)
treefd20e29c8730bbd28e3581ff8a9c5d7935b11d99
parentc093eadaa1aa2008f48b72ac4991f4cc0ab247d8 (diff)
downloadlibzhuyin-a8c700f1154aacfd1c5ca808a53b393f2f763e63.tar.gz
libzhuyin-a8c700f1154aacfd1c5ca808a53b393f2f763e63.tar.xz
libzhuyin-a8c700f1154aacfd1c5ca808a53b393f2f763e63.zip
fixes test_phrase_index_logger.cpp
-rw-r--r--tests/storage/test_phrase_index_logger.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/tests/storage/test_phrase_index_logger.cpp b/tests/storage/test_phrase_index_logger.cpp
index a16dbe0..f13f7ca 100644
--- a/tests/storage/test_phrase_index_logger.cpp
+++ b/tests/storage/test_phrase_index_logger.cpp
@@ -22,12 +22,12 @@
#include "zhuyin_internal.h"
/* TODO: check whether gb_char.bin and gb_char2.bin should be the same. */
int main(int argc, char * argv[]){
FacadePhraseIndex phrase_index;
MemoryChunk * chunk = new MemoryChunk;
- chunk->load("../../data/gb_char.bin");
+ chunk->load("../../data/tsi.bin");
phrase_index.load(1, chunk);
PhraseIndexRange range;
@@ -40,25 +40,25 @@ int main(int argc, char * argv[]){
MemoryChunk * new_chunk = new MemoryChunk;
phrase_index.store(1, new_chunk);
- new_chunk->save("/tmp/gb_char.bin");
+ new_chunk->save("/tmp/tsi.bin");
delete new_chunk;
chunk = new MemoryChunk;
- chunk->load("../../data/gb_char.bin");
+ chunk->load("../../data/tsi.bin");
new_chunk = new MemoryChunk;
assert(phrase_index.diff(1, chunk, new_chunk));
- new_chunk->save("/tmp/gb_char.dbin");
+ new_chunk->save("/tmp/tsi.dbin");
delete new_chunk;
chunk = new MemoryChunk;
- chunk->load("../../data/gb_char.bin");
+ chunk->load("../../data/tsi.bin");
phrase_index.load(1, chunk);
new_chunk = new MemoryChunk;
- new_chunk->load("/tmp/gb_char.dbin");
+ new_chunk->load("/tmp/tsi.dbin");
assert(phrase_index.merge(1, new_chunk));
chunk = new MemoryChunk;
phrase_index.store(1, chunk);
- chunk->save("/tmp/gb_char2.bin");
+ chunk->save("/tmp/tsi2.bin");
delete chunk;
printf("total freq:%d\n", phrase_index.get_phrase_index_total_freq());
@@ -22,12 +22,12 @@
#include "zhuyin_internal.h"
-/* TODO: check whether gb_char.bin and gb_char2.bin should be the same. */
+/* TODO: check whether tsi.bin and tsi2.bin should be the same. */
int main(int argc, char * argv[]){
FacadePhraseIndex phrase_index;